# Generated by Django 4.2.9 on 2024-01-25 12:38

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="DjangoCheckSEOPermissions",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
            ],
            options={
                "permissions": (
                    (
                        "use_django_check_seo",
                        "View the Check SEO button (if using Django CMS) and use Django Check SEO",
                    ),
                ),
                "managed": False,
                "default_permissions": (),
            },
        ),
    ]
