# Generated by Django 4.2 on 2025-03-10

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_check_seo", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="Keyword",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(max_length=255, unique=True, verbose_name="name"),
                ),
            ],
            options={
                "verbose_name": "keyword",
                "verbose_name_plural": "keywords",
            },
        ),
        migrations.CreateModel(
            name="Page",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "path",
                    models.CharField(max_length=500, unique=True, verbose_name="path"),
                ),
                (
                    "keywords",
                    models.ManyToManyField(
                        blank=True,
                        related_name="pages",
                        to="django_check_seo.keyword",
                        verbose_name="keywords",
                    ),
                ),
            ],
            options={
                "verbose_name": "page",
                "verbose_name_plural": "pages",
            },
        ),
    ]
